@@ -1,6 +1,6 @@
-c#######################################################################
+#######################################################################
 #
-# $Id: SC.pm,v 1.21 2009-11-14 10:18:40 gosha Exp $
+# $Id: SC.pm,v 1.22 2009-11-14 10:18:40 gosha Exp $
 #
 #              Socks Chain ( TCP only )
 #
